@@ -23,6 +23,7 @@ class API(object):
             )
         self.key = key
         self.secret = secret
+        self.session = requests.Session()
 
     @assembla_filter
     def stream(self, extra_params=None):
@@ -69,35 +70,34 @@ class API(object):
             response = self.cache[url]
         else:
             # Fetch the data
-            response = requests.get(
-                url=url,
-                headers={
-                    'X-Api-Key': self.key,
-                    'X-Api-Secret': self.secret,
-                },
-            )
+            headers = {
+                'X-Api-Key': self.key,
+                'X-Api-Secret': self.secret,
+            }
+            response = self.session.get(url=url, headers=headers)
             # If the cache is being used, update it
             if self.cache_responses:
                 self.cache[url] = response
 
         if response.status_code == 200:  # OK
             results = []
-            for json in response.json():
-                instance=model(data=json)
+            json_response = response.json()
+            for obj in json_response:
+                instance = model(data=obj)
                 instance.api = self
                 if space:
                     instance.space = space
                 results.append(instance)
-            # If `get_all` is True and the length of the current page is divisible by
-            # the maximum limit per page, then we try to fetch the next page
+            # If it looks like there are more pages to fetch,
+            # try and fetch the next one
             per_page = extra_params.get('per_page', None)
             if (
                 get_all
                 and per_page
-                and len(results)
-                and per_page % len(results) == 0
+                and len(json_response)
+                and per_page == len(json_response)
             ):
-                extra_params['page'] = extra_params['page'] + 1
+                extra_params['page'] += 1
                 results = results + self._get_json(model, space, rel_path, extra_params, get_all=get_all)
             return results
         elif response.status_code == 204:  # No Content
@@ -305,7 +305,7 @@ class Space(AssemblaObject):
 
         # Default params
         params = {
-            'per_page': 1000,
+            'per_page': settings.MAX_PER_PAGE,
             'report': 0,  # Report 0 is all tickets
         }
 
@@ -328,7 +328,7 @@ class Space(AssemblaObject):
         
         # Default params
         params = {
-            'per_page': 1000,
+            'per_page': settings.MAX_PER_PAGE,
         }
 
         if extra_params:
@@ -422,7 +422,6 @@ class Milestone(AssemblaObject):
 
 
 class Ticket(AssemblaObject):
-    @property
     def milestone(self, extra_params=None):
         """
         The Milestone that the Ticket is a part of
@@ -432,7 +431,6 @@ class Ticket(AssemblaObject):
             if milestones:
                 return milestones[0]
 
-    @property
     def user(self, extra_params=None):
         """
         The User currently assigned to the Ticket
@@ -445,7 +443,6 @@ class Ticket(AssemblaObject):
             if users:
                 return users[0]
 
-    @property
     def component(self, extra_params=None):
         """
         The Component currently assigned to the Ticket
@@ -462,20 +459,16 @@ class Ticket(AssemblaObject):
         if not hasattr(self, 'space'):
             raise AttributeError("A ticket must have a 'space' attribute before you can write it to Assembla.")
 
-        self.api = self.space.api
-
-        if self.get('number'):  # We are modifying an existing ticket
-            return self.api._put_json(
-                self,
-                space=self.space,
-                rel_path=self.space._build_rel_path('tickets'),
-            )
+        if self.get('number'):  # Modifying an existing ticket
+            method = self.space.api._put_json
         else:  # Creating a new ticket
-            return self.api._post_json(
-                self,
-                space=self.space,
-                rel_path=self.space._build_rel_path('tickets'),
-            )
+            method = self.space.api._post_json
+
+        return method(
+            self,
+            space=self.space,
+            rel_path=self.space._build_rel_path('tickets'),
+        )
 
     def delete(self):
         """
@@ -484,9 +477,7 @@ class Ticket(AssemblaObject):
         if not hasattr(self, 'space'):
             raise AttributeError("A ticket must have a 'space' attribute before you can remove it from Assembla.")
 
-        self.api = self.space.api
-
-        return self.api._delete_json(
+        return self.space.api._delete_json(
             self,
             space=self.space,
             rel_path=self.space._build_rel_path('tickets'),
